@@ -675,7 +675,9 @@ int main(int argc, char *argv[])
 		{NULL, 0, NULL, 0}
 	};
 
+#ifdef HAVE_PROGRAM_INVOCATION_NAME
 	program_invocation_name = program_invocation_short_name;
+#endif
 	setlocale(LC_ALL, "");
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	textdomain(PACKAGE);
@@ -764,15 +766,15 @@ int main(int argc, char *argv[])
 		int ret = EXIT_SUCCESS, i;
 		if (!preloadfile) {
 			if (!argc) {
-				ret != Preload(DEFAULT_PRELOAD);
+				ret |= Preload(DEFAULT_PRELOAD);
 			}
 		} else {
 			/* This happens when -pfile option is
 			 * used without space. */
-			Preload(preloadfile);
+			ret |= Preload(preloadfile);
 		}
 		for (i = 0; i < argc; i++)
-			Preload(argv[i]);
+			ret |= Preload(argv[i]);
 		return ret;
 	}
 
